# Don't generate requires on jpackage-utils and java-headless for
# provided pseudo-artifacts: com.sun:tools and sun.jdk:jconsole.
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}/maven-metadata/javapackages-metadata.xml$

# Avoid circular dependency on itself when bootstrapping
%{!?_with_bootstrap: %global bootstrap 0}

%bcond_without tests

Name:           javapackages-tools
Version:        4.7.0
Release:        %mkrel 6.1
Group:          Development/Java
Summary:        Macros and scripts for Java packaging support

License:        BSD
URL:            https://git.fedorahosted.org/git/javapackages.git
Source0:        https://fedorahosted.org/released/javapackages/javapackages-%{version}.tar.xz

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-lxml
BuildRequires:  python3-setuptools
BuildRequires:  python3-nose
BuildRequires:  python3-six
BuildRequires:  make
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  scl-utils-build
BuildRequires:  dia
%if ! 0%{?bootstrap}
BuildRequires:  javapackages-tools >= 4.0.0
BuildRequires:  xmvn-resolve >= 2
%endif

Requires:       coreutils
Requires:       findutils
Requires:       which
Requires:       lua
Requires:       python3-javapackages = %{version}-%{release}
Requires:       python3

Provides:       jpackage-utils = 1:%{version}-%{release}

%description
This package provides macros and scripts to support Java packaging.

%package -n maven-local
Summary:        Macros and scripts for Maven packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       xmvn-minimal >= 2
Requires:       xmvn-mojo >= 2
Requires:       xmvn-connector-aether >= 2
# POM files needed by maven itself
Requires:       apache-parent
# Common Maven plugins required by almost every build. It wouldn't make
# sense to explicitly require them in every package built with Maven.
Requires:       maven-assembly-plugin
Requires:       maven-compiler-plugin
Requires:       maven-jar-plugin
Requires:       maven-javadoc-plugin
Requires:       maven-resources-plugin
Requires:       maven-surefire-plugin
# Tests based on JUnit are very common and JUnit itself is small.
# Include JUnit provider for Surefire just for convenience.
Requires:       maven-surefire-provider-junit
# testng is quite common as well
Requires:       maven-surefire-provider-testng

%description -n maven-local
This package provides macros and scripts to support packaging Maven artifacts.

%package -n gradle-local
Summary:        Local mode for Gradle
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       gradle >= 2.2.1-2
Requires:       xmvn-connector-gradle >= 2

%description -n gradle-local
This package implements local mode for Gradle, which allows artifact
resolution using XMvn resolver.

%package -n ivy-local
Summary:        Local mode for Apache Ivy
Requires:       %{name} = %{version}-%{release}
Requires:       javapackages-local = %{version}-%{release}
Requires:       apache-ivy >= 2.3.0-8
Requires:       xmvn-connector-ivy >= 2

%description -n ivy-local
This package implements local mode for Apache Ivy, which allows
artifact resolution using XMvn resolver.

%package -n python3-javapackages
Summary:        Module for handling various files for Java packaging
Requires:       python3-lxml
Requires:       python3-six
Obsoletes:      python-javapackages < %{version}-%{release}

%description -n python3-javapackages
Module for handling, querying and manipulating of various files for Java
packaging in Linux distributions

%package doc
Summary:        Guide for Java packaging

%description doc
User guide for Java packaging and using utilities from javapackages-tools

%package -n javapackages-local
Summary:        Non-essential macros and scripts for Java packaging support
Requires:       %{name} = %{version}-%{release}
Requires:       xmvn-install >= 2
Requires:       xmvn-subst >= 2
Requires:       xmvn-resolve >= 2
# Java build systems don't have hard requirement on java-devel, so it should be there
Requires:       java-devel

%description -n javapackages-local
This package provides non-essential macros and scripts to support Java packaging.

%prep
%setup -q -n javapackages-%{version}

sed -i '/fedora-review/d' install

%build
%configure --pyinterpreter=%{__python3}
./build

%install
./install
sed -e 's/.[17]$/&.*/' -e 's/.py$/&*/' -i files-*

pushd python
  %{__python3} setup.py install -O1 --skip-build --root %{buildroot}
popd

# (tv) fix conflicts with rpm:
perl -pi -e 'undef $_ if m!dir /usr/lib/rpm/fileattrs!' files-common 

%if %{with tests}
%check
./check
%endif

%files -f files-common

%files -n javapackages-local -f files-local

%files -n maven-local -f files-maven

%files -n gradle-local -f files-gradle

%files -n ivy-local -f files-ivy

%files -n python3-javapackages
%license LICENSE
%{python3_sitelib}/javapackages*

%files doc -f files-doc
%license LICENSE




%changelog
* Sun May 07 2017 neoclust <neoclust> 4.7.0-6.1.mga6
+ Revision: 1099554
- Rebuild against new xmvn

* Sun Nov 27 2016 daviddavid <daviddavid> 4.7.0-2.mga6
+ Revision: 1070450
- Add Requires on which (rhbz#1396395)

* Thu Apr 21 2016 tv <tv> 4.7.0-1.mga6
+ Revision: 1003969
- new release
- new release

* Thu Feb 25 2016 neoclust <neoclust> 4.6.0-5.mga6
+ Revision: 978920
- Move mvn_build and builddep to javapackages-local

* Sat Dec 26 2015 daviddavid <daviddavid> 4.6.0-4.mga6
+ Revision: 915358
- do a non bootstrap build

* Mon Dec 21 2015 tv <tv> 4.6.0-3.mga6
+ Revision: 913096
- fix conflict with rpm

* Mon Dec 21 2015 tv <tv> 4.6.0-2.mga6
+ Revision: 912977
- unbreak BS
- simplify

* Mon Dec 21 2015 neoclust <neoclust> 4.6.0-1.mga6
+ Revision: 912809
- Add bootstrap option

  + zezinho <zezinho>
    - new version

* Sat Jul 25 2015 daviddavid <daviddavid> 4.1.0-16.mga6
+ Revision: 857176
- add Patch6 from Fedora to fix missing space between xmlns declarations

* Fri Dec 26 2014 pterjan <pterjan> 4.1.0-15.mga5
+ Revision: 806058
- Clean rebuild
- Fix a conflict with rpm

* Fri Dec 26 2014 pterjan <pterjan> 4.1.0-13.mga5
+ Revision: 806046
- Restore wrongly dropped epoch

  + dmorgan <dmorgan>
    - Fix Requires

* Fri Dec 26 2014 pterjan <pterjan> 4.1.0-11.mga5
+ Revision: 806039
- Sync with Fedora 21

* Tue Dec 02 2014 dmorgan <dmorgan> 4.1.0-10.mga5
+ Revision: 800278
- Disable this non-sense minimal check

* Mon Dec 01 2014 dmorgan <dmorgan> 4.1.0-9.mga5
+ Revision: 800219
- Rebuild because of removed packages

* Sat Nov 29 2014 cjw <cjw> 4.1.0-8.mga5
+ Revision: 799862
- add conflicts: python-pyxml because maven.prov doesnt work with this package installed
- add back maven-metadata

* Sat Nov 29 2014 cjw <cjw> 4.1.0-7.mga5
+ Revision: 799833
- do not build maven-related subpackages because of broken dependencies, they can be re-added later
- rebuild for task-obsolete

  + sander85 <sander85>
    - Depends on broken java stack

* Sun Nov 23 2014 luigiwalser <luigiwalser> 4.1.0-6.mga5
+ Revision: 798368
- do not require dropped httpcomponents-project

* Mon Nov 03 2014 philippem <philippem> 4.1.0-5.mga5
+ Revision: 795336
- enable tests

* Thu Oct 30 2014 pterjan <pterjan> 4.1.0-4.mga5
+ Revision: 794780
- Fix ivy-local dependency

* Thu Oct 30 2014 pterjan <pterjan> 4.1.0-3.mga5
+ Revision: 794765
- Drop fedora-review-plugin-java

* Thu Oct 30 2014 dmorgan <dmorgan> 4.1.0-2.mga5
+ Revision: 794685
- Rebuild after bootstrap
- New version

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

  + tv <tv>
    - rebuild for missing pythoneggs deps

  + pterjan <pterjan>
    - 4.1.0
    - Sync wiith fedora

* Sun Jun 15 2014 dmorgan <dmorgan> 3.4.1-1.mga5
+ Revision: 636288
- New version

* Sat May 31 2014 pterjan <pterjan> 3.4.0-12.mga5
+ Revision: 628272
- Rebuild for new Python

* Mon May 19 2014 dmorgan <dmorgan> 3.4.0-11.mga5
+ Revision: 623745
- Rebuild against java stack
- Revert to version 3.4.0
- New version

* Sun May 11 2014 dmorgan <dmorgan> 3.4.2-1.mga5
+ Revision: 621873
- New version 3.4.2

* Sun Jan 26 2014 dmorgan <dmorgan> 3.4.0-9.mga4
+ Revision: 568237
- Fix conflict against older maven

* Wed Dec 25 2013 dmorgan <dmorgan> 3.4.0-8.mga4
+ Revision: 560577
- Add one more common require

* Mon Dec 16 2013 dmorgan <dmorgan> 3.4.0-7.mga4
+ Revision: 557424
- Requires mvn(javax.mail:mail) in maven-local

* Tue Oct 22 2013 umeabot <umeabot> 3.4.0-6.mga4
+ Revision: 545411
- Mageia 4 Mass Rebuild

  + dmorgan <dmorgan>
    - Remove provides not needed anymore

* Mon Oct 21 2013 dmorgan <dmorgan> 3.2.4-3.mga4
+ Revision: 540794
- More provides

* Mon Oct 21 2013 dmorgan <dmorgan> 3.2.4-2.mga4
+ Revision: 539855
- Bump release to rebuild
- Downgrade to version 3.2.4 to fix maven install/build

* Mon Oct 21 2013 dmorgan <dmorgan> 3.4.0-5.mga4
+ Revision: 537808
- Add back google-guice-sisu-guice-noaop demap

* Tue Oct 15 2013 dmorgan <dmorgan> 3.4.0-4.mga4
+ Revision: 501226
- New version

* Tue Oct 15 2013 dmorgan <dmorgan> 3.3.1-4.mga4
+ Revision: 500552
- Remove wrong patch

* Mon Oct 14 2013 pterjan <pterjan> 3.3.1-3.mga4
+ Revision: 497834
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 12 2013 dmorgan <dmorgan> 3.3.1-2.mga4
+ Revision: 495597
- Remove SYSTEM version provide

* Wed Oct 09 2013 dmorgan <dmorgan> 3.3.1-1.mga4
+ Revision: 493927
- New version 3.3.1

* Fri Sep 20 2013 dmorgan <dmorgan> 3.2.1-2.mga4
+ Revision: 482524
- Fix requires for xsltproc

* Fri Sep 20 2013 dmorgan <dmorgan> 3.2.1-1.mga4
+ Revision: 481757
- New version 3.2.1

* Fri Sep 20 2013 dmorgan <dmorgan> 3.1.2-1.mga4
+ Revision: 481667
- New version 3.1.2

* Thu Sep 19 2013 dmorgan <dmorgan> 3.1.1-3.mga4
+ Revision: 481583
- Obsolete/providesjava-rpmbuild

* Thu Sep 19 2013 dmorgan <dmorgan> 3.1.1-2.mga4
+ Revision: 481568
- More provides

* Thu Sep 19 2013 dmorgan <dmorgan> 3.1.1-1.mga4
+ Revision: 481562
- New version 3.1.1

* Thu Sep 19 2013 dmorgan <dmorgan> 3.0.2-2.mga4
+ Revision: 481442
- Obsolete jpackage-utils
- FIx file list

* Thu Sep 19 2013 dmorgan <dmorgan> 3.0.2-1.mga4
+ Revision: 481436
- New upstream major version 3.0.2

* Fri Jul 12 2013 dmorgan <dmorgan> 0.15.0-6.mga4
+ Revision: 453461
- Renable local scripts

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-5.mga4
+ Revision: 452558
- Enable debug by default

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-4.mga4
+ Revision: 452552
- Fix conflicts with maven

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-3.mga4
+ Revision: 452548
- Do not own fileattr dir

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-2.mga4
+ Revision: 452477
- Fix buildrequires

* Wed Jul 10 2013 dmorgan <dmorgan> 0.15.0-1.mga4
+ Revision: 452465
- New version

* Tue Feb 19 2013 dmorgan <dmorgan> 0.12.0-2.mga3
+ Revision: 399298
- Fix conflict with maven

* Tue Feb 19 2013 dmorgan <dmorgan> 0.12.0-1.mga3
+ Revision: 399281
- Fix release to 1

* Tue Feb 19 2013 dmorgan <dmorgan> 0.12.0-0.mga3
+ Revision: 399275
- New version
- New version 0.10.0

* Sat Jan 12 2013 umeabot <umeabot> 0.8.0-2.mga3
+ Revision: 354844
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 01 2012 dmorgan <dmorgan> 0.8.0-1.mga3
+ Revision: 324009
- New version ( add maven-local package)

* Mon Sep 10 2012 dmorgan <dmorgan> 0.6.0-1.mga3
+ Revision: 291860
- Update to upstream version 0.6.0
- Make maven provides versioned
- Add additional pom_ macros to simplify additional pom editing

* Sun Jul 08 2012 dmorgan <dmorgan> 0.4.0-3.mga3
+ Revision: 268933
- Fix again conflict with rpm

* Sun Jul 08 2012 dmorgan <dmorgan> 0.4.0-2.mga3
+ Revision: 268929
- Remove wrong require

* Sun Jul 08 2012 dmorgan <dmorgan> 0.4.0-1.mga3
+ Revision: 268924
- New version

* Tue Jun 12 2012 dmorgan <dmorgan> 0.3.1-1.mga3
+ Revision: 260022
- imported package javapackages-tools


* Tue Mar  6 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.1-1
- Create maven provides from fragments instead of poms

* Thu Feb 16 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.0-3
- Fix maven_depmap installation

* Wed Feb 15 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.0-2
- Add conflicts with older jpackage-utils

* Wed Feb 15 2012 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.3.0-1
- Initial version split from jpackage-utils

